@@ -62,6 +62,9 @@ FAILEDOPERATION_INSTANCECANNOTRETURN = 'FailedOperation.InstanceCanNotReturn'
 # 实例退费失败。
 FAILEDOPERATION_INSTANCERETURNFAILED = 'FailedOperation.InstanceReturnFailed'
 
+# 日志不存在。
+FAILEDOPERATION_LOGNOTEXISTED = 'FailedOperation.LogNotExisted'
+
 # 修改账号权限失败。
 FAILEDOPERATION_MODIFYRIGHTFAILED = 'FailedOperation.ModifyRightFailed'
 
@@ -137,7 +140,7 @@ INTERNALERROR_DBOPERATIONFAILED = 'InternalError.DbOperationFailed'
 # 查询独享集群信息失败。
 INTERNALERROR_FENCEERROR = 'InternalError.FenceError'
 
-# 获取数据库加密秘钥失败。
+# 获取数据库加密密钥失败。
 INTERNALERROR_GETCIPHERTEXTFAILED = 'InternalError.GetCipherTextFailed'
 
 # 获取数据库实例参数失败。
@@ -410,6 +413,9 @@ UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 # 没有权限操作该接口或资源。
 UNAUTHORIZEDOPERATION_PERMISSIONDENIED = 'UnauthorizedOperation.PermissionDenied'
 
+# 不支持该数据库版本。
+UNSUPPORTEDOPERATION_DBVERSIONNOTSUPPORTED = 'UnsupportedOperation.DbVersionNotSupported'
+
 # 不支持的无效操作。
 UNSUPPORTEDOPERATION_INVALIDOPERATION = 'UnsupportedOperation.InvalidOperation'
 
